import pprint
import re

import sys
import urllib
from urlparse import urlparse

import requests


def slugify(value):
    """
    Normalizes string, converts to lowercase, removes non-alpha characters,
    and converts spaces to hyphens.
    """
    import unicodedata
    if sys.version_info < (3, 0):
        value = str(value).decode()
    value = unicodedata.normalize('NFKD', value).encode('ascii', 'ignore').decode()
    value = re.sub('[^\w\s-]', '', value).strip().lower()

    return re.sub('[-\s]+', '-', value)


def sort_video_links(video_links):
    return sorted(video_links, key=lambda k: re.search(r'\d+', k['res']).group())

"""
def drive_link_generator(link, session=None):
    if session is None:
        session = requests.Session()
    url = urlparse(link)
    docid = url.path.split('/')[3]
    req = session.get('https://drive.google.com/get_video_info?docid=' + docid + '&authuser=0')
    drive_info_text = req.text
    drive_info_dict = {}
    for part in drive_info_text.split('&'):
        drive_info_dict[part.split('=')[0]] = part.split('=')[1]
    print(drive_info_dict)
    stream_map = drive_info_dict['url_encoded_fmt_stream_map']
    stream_map = urllib.unquote(stream_map).decode('utf8')
    print(stream_map)
    stream_parts = stream_map.split(',')
    stream_map = []
    for stream_part in stream_parts:
        link_parts = stream_part.split('&')
        link = {}
        for link_part in link_parts:
            link[link_part.split('=')[0]] = link_part.split('=')[1]
        pprint.pprint(link)
        stream_map.append(link)
    print(session.cookies)
"""


import json
import re

import demjson
import execjs
import requests
from pyquery import PyQuery as pq

from .base import BaseDiziCrawler


class DiziayCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://diziay.com/izle/" + self.episode['dizi_url'] + "-" + \
               str(self.episode['season']) + "-sezon-" + str(self.episode['episode']) + "-bolum/"

    def after_body_loaded(self, text):
        part_id = re.search('var FIRST_PART =([0-9]+);', text).group(1)
        result = self.session.post("http://diziay.com/ajax/getpart", data={'part_id':part_id})

        if result.status_code == 200:
            self.after_part_loaded(result.text)

        self.episode['site'] = 'diziay'

    def after_part_loaded(self, text):
        page_dom = pq(text)
        player_address = page_dom("iframe").attr("src")
        content =self.session.get(player_address).text

        self.after_sources_loaded(content)

    def after_sources_loaded(self, text):
        eval_text = re.search(r'(var source = .*?;)', text).group(1)
        js_func = "function b(){" + eval_text + "; return JSON.stringify(source);}"
        ctx = execjs.compile(js_func)
        sources = json.loads(ctx.call("b"))

        for source in sources:
            if 'p' not in source['label']:
                source['label'] += 'p'
            video_link = {"res": source['label'], "url": source['file']}
            if "mp4" in source['type']:
                self.episode['video_links'].append(video_link)



import json
import re

import execjs
import requests

from pyquery import PyQuery as pq
from .base import BaseMovieCrawler


class _720pizleCrawler(BaseMovieCrawler):
    def __init__(self):
        BaseMovieCrawler.__init__(self)

    def generate_movie_page_url(self):
        return "http://720pizle.com/izle/altyazi/" + self.movie['movie_url'] + ".html"

    def after_body_loaded(self, text):
        page_dom = pq(text)
        player_address = "http://720pizle.com/player/plusplayer2.asp?v=" + page_dom(".plusplayerV2").text()

        text = requests.get(player_address, headers=BaseMovieCrawler.headers).text

        video_altyazi_test = re.search(r"(var altyazi(?s).*.\$\(d)", text).group(1)[:-3]
        ctx = execjs.compile('function b(){\n' + video_altyazi_test + 'return [video, altyazi];}')
        [sources, subs] = ctx.call("b")

        for source in sources:
            video_link = {"res": source['label'], "url": "http://720pizle.com" + source['file']}
            self.movie['video_links'].append(video_link)

        for source in subs:
            if source['label'][0] == 'T':
                source['label'] = 'tr'
            elif source['label'][0] == 'E':
                source['label'] = 'en'

            subtitle_link = {"lang": source['label'], "url": source['file'], "kind": "vtt"}
            self.movie['subtitle_links'].append(subtitle_link)



from pprint import pprint

from vizontele.crawler import DiziCrawler
episode = DiziCrawler('diziay', 'the flash', 4, 3).get_sources()
assert len(episode['video_links']) > 0
pprint('Diziay test successful')

episode = DiziCrawler('dizist', 'travelers', 2, 2).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizist test successful')

episode = DiziCrawler('dizimag', 'the-walking-deaddd', 8, 1).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizimag test successful')

episode = DiziCrawler('dizipub', 'the-office', 1, 2).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizipub test successful')

episode = DiziCrawler('dizilab', 'rick-and-morty', 3, 6).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizilab test successful')

episode = DiziCrawler('sezonlukdizi', 'the-big-bang-theory', 11, 1).get_sources()
assert len(episode['video_links']) > 0
pprint('Sezonlukdizi test successful')

episode = DiziCrawler('dizibox', 'doctor-who', 10, 8).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizibox test successful')

episode = DiziCrawler('dizimek', 'how i met your mother', 1, 1).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizimek test successful')